# eric7.DebugClients.Python.eric7dbgstub

Module implementing a debugger stub for remote debugging.

### Global Attributes

__scriptname
debugger
ericpath

### Classes

None

### Functions

initDebugger | Module function to initialize a debugger for remote debugging.
runcall | Module function mimicing the Pdb interface.
setScriptname | Module function to set the script name to be reported back to the IDE.
startDebugger | Module function used to start the remote debugger.

## initDebugger

initDebugger(kind="standard")

Module function to initialize a debugger for remote debugging.

kind (str)
  type of debugger ("standard" or "threads")

Return:
  flag indicating success

Return Type:
  bool

Raises ValueError:
  raised to indicate a wrong debugger kind

Up

## runcall

runcall(func, *args)

Module function mimicing the Pdb interface.

func (function)
  function to be called
*args (list of Any)
  arguments being passed to func

Return:
  the function result

Return Type:
  Any

Up

## setScriptname

setScriptname(name)

Module function to set the script name to be reported back to the IDE.

name (str)
  absolute path name of the script

Up

## startDebugger

startDebugger(enableTrace=True, exceptions=True, tracePython=False, redirect=True)

Module function used to start the remote debugger.

enableTrace (bool)
  flag to enable the tracing function
exceptions (bool)
  flag to enable exception reporting of the IDE
tracePython (bool)
  flag to enable tracing into the Python library
redirect (bool)
  flag indicating redirection of stdin, stdout and stderr

Up